==> primefaces-11.0.0-RC1.jar: META-INF/resources/primefaces/locales/locale-tr.js <==
/** Turkish */
PrimeFaces.locales['tr'] = {
    closeText: 'Kapat',
    prevText: 'Geri',
    nextText: 'İleri',
    monthNames: ['Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs', 'Haziran', 'Temmuz', 'Ağustos', 'Eylül', 'Ekim', 'Kasım', 'Aralık'],
    monthNamesShort: ['Oca', 'Şub', 'Mar', 'Nis', 'May', 'Haz', 'Tem', 'Ağu', 'Eyl', 'Eki', 'Kas', 'Ara'],
    dayNames: ['Pazar', 'Pazartesi', 'Salı', 'Çarşamba', 'Perşembe', 'Cuma', 'Cumartesi'],
    dayNamesShort: ['Pz', 'Pt', 'Sa', 'Ça', 'Pe', 'Cu', 'Ct'],
    dayNamesMin: ['Pz', 'Pt', 'Sa', 'Ça', 'Pe', 'Cu', 'Ct'],
    weekHeader: 'Hf',
    weekNumberTitle: 'Hf',
    firstDay: 1,
    isRTL: false,
    showMonthAfterYear: false,
    yearSuffix: '',
    timeOnlyTitle: 'Zaman Seçiniz',
    timeText: 'Zaman',
    hourText: 'Saat',
    minuteText: 'Dakika',
    secondText: 'Saniye',
    millisecondText: 'Milisaniye',
    currentText: 'Geçerli Tarih',
    ampm: false,
    year: 'Yıl',
    month: 'Ay',
    week: 'Hafta',
    day: 'Gün',
    list: 'Agenda',
    allDayText: 'Tüm Gün',
    moreLinkText: 'Daha Fazla...',
    noEventsText: 'Etkinlik Yok',
    today: 'Bugün',
    clear: 'Temizle',
    aria: {
        'paginator.PAGE': 'Sayfa {0}',
        'calendar.BUTTON': 'Takvimi Göster',
        'datatable.sort.ASC': 'Sütunu artan sıralamak için etkinleştir',
        'datatable.sort.DESC': 'Sütunu azalan sıralamak için etkinleştir',
        'columntoggler.CLOSE': 'Kapat',
        'overlaypanel.CLOSE': 'Kapat'
    },
    messages: {  //optional for Client Side Validation
        'javax.faces.component.UIInput.REQUIRED': '{0}: Doğrulama Hatası: Değer gerekli.',
        'javax.faces.converter.IntegerConverter.INTEGER': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.IntegerConverter.INTEGER_detail': '{2}: \'{0}\' sayısı -2147483648 ve 2147483647 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.DoubleConverter.DOUBLE': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.DoubleConverter.DOUBLE_detail': '{2}: \'{0}\' sayısı 4.9E-324 ve 1.7976931348623157E308 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL': '{2}: \'{0}\' işaretli bir ondalık sayı olmalıdır.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL_detail': '{2}: \'{0}\' sıfır veya daha fazla basamaktan oluşan işaretli bir ondalık sayı olmalıdır, ardından bir ondalık virgül veya kesir gelebilir. Örnek: {1}.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER_detail': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır. Örnek: {1}.',
        'javax.faces.converter.ByteConverter.BYTE': '{2}: \'{0}\' sayısı 0 ve 255 arasında olmalıdır.',
        'javax.faces.converter.ByteConverter.BYTE_detail': '{2}: \'{0}\' sayısı 0 ve 255 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.CharacterConverter.CHARACTER': '{1}: \'{0}\' değeri geçerli bir karakter olmalı.',
        'javax.faces.converter.CharacterConverter.CHARACTER_detail': '{1}: \'{0}\' değeri geçerli bir ASCII karakteri olmalı.',
        'javax.faces.converter.ShortConverter.SHORT': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.ShortConverter.SHORT_detail': '{2}: \'{0}\' sayısı -32768 ve 32767 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.BooleanConverter.BOOLEAN': '{1}: \'{0}\' değeri \'true\' (doğru) yada \'false\' (yanlış) olmalıdır.',
        'javax.faces.converter.BooleanConverter.BOOLEAN_detail': '{1}: \'{0}\' değeri \'true\' (doğru) yada \'false\' (yanlış) olmalıdır. \'true\' dışındaki değerler \'false\' olarak değerlendirilir.',
        'javax.faces.validator.LongRangeValidator.MAXIMUM': '{1}: Doğrulama Hatası: Değer izin verilen maksimum değerden daha büyük: \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.MINIMUM': '{1}: Doğrulama Hatası: Değer izin verilen minimum değerden daha düşük: \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.NOT_IN_RANGE': '{2}: Doğrulama Hatası: Belirtilen öznitelik {0} ve {1} değerleri arasında değil.',
        'javax.faces.validator.LongRangeValidator.TYPE={0}': 'Doğrulama Hatası: Değer doğru türde değil.',
        'javax.faces.validator.DoubleRangeValidator.MAXIMUM': '{1}: Doğrulama Hatası: Değer izin verilen maksimum değerden daha büyük: \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.MINIMUM': '{1}: Doğrulama Hatası: Değer izin verilen minimum değerden daha düşük: \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.NOT_IN_RANGE': '{2}: Doğrulama Hatası: Belirtilen öznitelik {0} ve {1} değerleri arasında değil.',
        'javax.faces.validator.DoubleRangeValidator.TYPE={0}': 'Doğrulama Hatası: Değer doğru türde değil.',
        'javax.faces.converter.FloatConverter.FLOAT': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.FloatConverter.FLOAT_detail': '{2}: \'{0}\' sayısı 1.4E-45 ve 3.4028235E38 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.DATE': '{2}: \'{0}\' değeri tarih olarak anlaşılamadı.',
        'javax.faces.converter.DateTimeConverter.DATE_detail': '{2}: \'{0}\' değeri  tarih olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.TIME': '{2}: \'{0}\' değeri  saat olarak anlaşılamadı.',
        'javax.faces.converter.DateTimeConverter.TIME_detail': '{2}: \'{0}\' değeri  saat olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.DATETIME': '{2}: \'{0}\' değeri tarih ve saat olarak anlaşılamadı.',
        'javax.faces.converter.DateTimeConverter.DATETIME_detail': '{2}: \'{0}\' değeri tarih ve saat olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.PATTERN_TYPE': '{1}: \'{0}\' değerini dönüştürmek için \'pattern\' yada \'type\' değeri girilmelidir.',
        'javax.faces.converter.NumberConverter.CURRENCY': '{2}: \'{0}\' değeri parasal birim olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.CURRENCY_detail': '{2}: \'{0}\' değeri parasal birim olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.NumberConverter.PERCENT': '{2}: \'{0}\' değeri yüzdesel olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.PERCENT_detail': '{2}: \'{0}\' değeri yüzdesel olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.NumberConverter.NUMBER': '{2}: \'{0}\' değeri sayı olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.NUMBER_detail': '{2}: \'{0}\' değeri sayı olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.NumberConverter.PATTERN': '{2}: \'{0}\' değeri sayı deseni olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.PATTERN_detail': '{2}: \'{0}\' değeri sayı deseni olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.validator.LengthValidator.MINIMUM': '{1}: Doğrulama Hatası: Uzunluk, izin verilen minimum değerden daha az: \'{0}\'.',
        'javax.faces.validator.LengthValidator.MAXIMUM': '{1}: Doğrulama Hatası: Uzunluk izin verilen maksimum değerden daha büyük: \'{0}\'.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET': 'Regex deseni boş olamaz.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET_detail': 'Regex deseni boş değer alamaz.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED': 'Regex deseni eşleşmedi.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED_detail': '\'{0}\' ile regex deseni eşleşmedi.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION': 'Regex hatası.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION_detail': 'Regex hatası, \'{0}\'.',
        'javax.faces.validator.BeanValidator.MESSAGE': '{0}',
        'javax.validation.constraints.AssertFalse.message': 'Değer \'false\' (yanlış) olmak zorunda.',
        'javax.validation.constraints.AssertTrue.message': 'Değer \'true\' (doğru) olmak zorunda.',
        'javax.validation.constraints.DecimalMax.message': '{0} veya daha düşük olmalı.',
        'javax.validation.constraints.DecimalMin.message': '{0} veya daha yüksek olmalı.',
        'javax.validation.constraints.Digits.message': 'Sayısal değer sınırların dışında (&lt;{0} basamak&gt;.&lt;{1} basamak&gt; olmalı).',
        'javax.validation.constraints.Future.message': 'Gelecek bir tarih olmalı.',
        'javax.validation.constraints.Max.message': '{0} veya daha düşük olmalı.',
        'javax.validation.constraints.Min.message': '{0} veya daha yüksek olmalı',
        'javax.validation.constraints.NotNull.message': '\'null\' (boş) olmayabilir.',
        'javax.validation.constraints.Null.message': '\'null\' (boş) olmalıdır.',
        'javax.validation.constraints.Past.message': 'Geçmiş bir tarih olmalıdır.',
        'javax.validation.constraints.Pattern.message': '"{0}" ile eşleşmelidir.',
        'javax.validation.constraints.Size.message': '{0} ile {1} arasında bir değer olmalıdır.'
    }
};

==> primefaces-13.0.0-RC1.jar: META-INF/resources/primefaces/locales/locale-tr.js <==
/** Turkish */
PrimeFaces.locales['tr'] = {
    closeText: 'Kapat',
    prevText: 'Geri',
    nextText: 'İleri',
    monthNames: ['Ocak', 'Şubat', 'Mart', 'Nisan', 'Mayıs', 'Haziran', 'Temmuz', 'Ağustos', 'Eylül', 'Ekim', 'Kasım', 'Aralık'],
    monthNamesShort: ['Oca', 'Şub', 'Mar', 'Nis', 'May', 'Haz', 'Tem', 'Ağu', 'Eyl', 'Eki', 'Kas', 'Ara'],
    dayNames: ['Pazar', 'Pazartesi', 'Salı', 'Çarşamba', 'Perşembe', 'Cuma', 'Cumartesi'],
    dayNamesShort: ['Pz', 'Pt', 'Sa', 'Ça', 'Pe', 'Cu', 'Ct'],
    dayNamesMin: ['Pz', 'Pt', 'Sa', 'Ça', 'Pe', 'Cu', 'Ct'],
    weekHeader: 'Hf',
    weekNumberTitle: 'Hf',
    firstDay: 1,
    isRTL: false,
    showMonthAfterYear: false,
    yearSuffix: '',
    timeOnlyTitle: 'Zaman Seçiniz',
    timeText: 'Zaman',
    hourText: 'Saat',
    minuteText: 'Dakika',
    secondText: 'Saniye',
    millisecondText: 'Milisaniye',
    currentText: 'Geçerli Tarih',
    ampm: false,
    year: 'Yıl',
    month: 'Ay',
    week: 'Hafta',
    day: 'Gün',
    list: 'Agenda',
    allDayText: 'Tüm Gün',
    moreLinkText: 'Daha Fazla...',
    noEventsText: 'Etkinlik Yok',
    today: 'Bugün',
    clear: 'Temizle',
    aria: {
        'paginator.PAGE': 'Sayfa {0}',
        'calendar.BUTTON': 'Takvimi Göster',
        'datatable.sort.ASC': 'Sütunu artan sıralamak için etkinleştir',
        'datatable.sort.DESC': 'Sütunu azalan sıralamak için etkinleştir',
        'columntoggler.CLOSE': 'Kapat',
        'overlaypanel.CLOSE': 'Kapat',
        'colorpicker.OPEN': 'Renk seçiciyi aç',
        'colorpicker.CLOSE': 'Renk seçiciyi kapat',
        'colorpicker.CLEAR': 'Seçili rengi temizle',
        'colorpicker.MARKER': 'Doygunluk: {s}. Parlaklık: {v}.',
        'colorpicker.HUESLIDER': 'Ton kaydırıcı',
        'colorpicker.ALPHASLIDER': 'Opaklık kaydırıcısı',
        'colorpicker.INPUT': 'Renk değeri alanı',
        'colorpicker.FORMAT': 'Renk formatı',
        'colorpicker.SWATCH': 'Renk örneği',
        'colorpicker.INSTRUCTION': 'Doygunluk ve parlaklık seçici. Seçmek için yukarı, aşağı, sol ve sağ ok tuşlarını kullanın.'
    },
    messages: {  //optional for Client Side Validation
        'javax.faces.component.UIInput.REQUIRED': '{0}: Doğrulama Hatası: Değer gerekli.',
        'javax.faces.converter.IntegerConverter.INTEGER': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.IntegerConverter.INTEGER_detail': '{2}: \'{0}\' sayısı -2147483648 ve 2147483647 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.DoubleConverter.DOUBLE': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.DoubleConverter.DOUBLE_detail': '{2}: \'{0}\' sayısı 4.9E-324 ve 1.7976931348623157E308 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL': '{2}: \'{0}\' işaretli bir ondalık sayı olmalıdır.',
        'javax.faces.converter.BigDecimalConverter.DECIMAL_detail': '{2}: \'{0}\' sıfır veya daha fazla basamaktan oluşan işaretli bir ondalık sayı olmalıdır, ardından bir ondalık virgül veya kesir gelebilir. Örnek: {1}.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.BigIntegerConverter.BIGINTEGER_detail': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır. Örnek: {1}.',
        'javax.faces.converter.ByteConverter.BYTE': '{2}: \'{0}\' sayısı 0 ve 255 arasında olmalıdır.',
        'javax.faces.converter.ByteConverter.BYTE_detail': '{2}: \'{0}\' sayısı 0 ve 255 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.CharacterConverter.CHARACTER': '{1}: \'{0}\' değeri geçerli bir karakter olmalı.',
        'javax.faces.converter.CharacterConverter.CHARACTER_detail': '{1}: \'{0}\' değeri geçerli bir ASCII karakteri olmalı.',
        'javax.faces.converter.ShortConverter.SHORT': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.ShortConverter.SHORT_detail': '{2}: \'{0}\' sayısı -32768 ve 32767 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.BooleanConverter.BOOLEAN': '{1}: \'{0}\' değeri \'true\' (doğru) yada \'false\' (yanlış) olmalıdır.',
        'javax.faces.converter.BooleanConverter.BOOLEAN_detail': '{1}: \'{0}\' değeri \'true\' (doğru) yada \'false\' (yanlış) olmalıdır. \'true\' dışındaki değerler \'false\' olarak değerlendirilir.',
        'javax.faces.validator.LongRangeValidator.MAXIMUM': '{1}: Doğrulama Hatası: Değer izin verilen maksimum değerden daha büyük: \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.MINIMUM': '{1}: Doğrulama Hatası: Değer izin verilen minimum değerden daha düşük: \'{0}\'.',
        'javax.faces.validator.LongRangeValidator.NOT_IN_RANGE': '{2}: Doğrulama Hatası: Belirtilen öznitelik {0} ve {1} değerleri arasında değil.',
        'javax.faces.validator.LongRangeValidator.TYPE': '{0}: Doğrulama Hatası: Değer doğru türde değil.',
        'javax.faces.validator.DoubleRangeValidator.MAXIMUM': '{1}: Doğrulama Hatası: Değer izin verilen maksimum değerden daha büyük: \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.MINIMUM': '{1}: Doğrulama Hatası: Değer izin verilen minimum değerden daha düşük: \'{0}\'.',
        'javax.faces.validator.DoubleRangeValidator.NOT_IN_RANGE': '{2}: Doğrulama Hatası: Belirtilen öznitelik {0} ve {1} değerleri arasında değil.',
        'javax.faces.validator.DoubleRangeValidator.TYPE': '{0}: Doğrulama Hatası: Değer doğru türde değil.',
        'javax.faces.converter.FloatConverter.FLOAT': '{2}: \'{0}\' sayısı bir veya daha fazla rakamdan oluşmalıdır.',
        'javax.faces.converter.FloatConverter.FLOAT_detail': '{2}: \'{0}\' sayısı 1.4E-45 ve 3.4028235E38 arasında olmalıdır. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.DATE': '{2}: \'{0}\' değeri tarih olarak anlaşılamadı.',
        'javax.faces.converter.DateTimeConverter.DATE_detail': '{2}: \'{0}\' değeri  tarih olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.TIME': '{2}: \'{0}\' değeri  saat olarak anlaşılamadı.',
        'javax.faces.converter.DateTimeConverter.TIME_detail': '{2}: \'{0}\' değeri  saat olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.DATETIME': '{2}: \'{0}\' değeri tarih ve saat olarak anlaşılamadı.',
        'javax.faces.converter.DateTimeConverter.DATETIME_detail': '{2}: \'{0}\' değeri tarih ve saat olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.DateTimeConverter.PATTERN_TYPE': '{1}: \'{0}\' değerini dönüştürmek için \'pattern\' yada \'type\' değeri girilmelidir.',
        'javax.faces.converter.NumberConverter.CURRENCY': '{2}: \'{0}\' değeri parasal birim olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.CURRENCY_detail': '{2}: \'{0}\' değeri parasal birim olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.NumberConverter.PERCENT': '{2}: \'{0}\' değeri yüzdesel olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.PERCENT_detail': '{2}: \'{0}\' değeri yüzdesel olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.NumberConverter.NUMBER': '{2}: \'{0}\' değeri sayı olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.NUMBER_detail': '{2}: \'{0}\' değeri sayı olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.converter.NumberConverter.PATTERN': '{2}: \'{0}\' değeri sayı deseni olarak anlaşılamadı.',
        'javax.faces.converter.NumberConverter.PATTERN_detail': '{2}: \'{0}\' değeri sayı deseni olarak anlaşılamadı. Örnek: {1}.',
        'javax.faces.validator.LengthValidator.MINIMUM': '{1}: Doğrulama Hatası: Uzunluk, izin verilen minimum değerden daha az: \'{0}\'.',
        'javax.faces.validator.LengthValidator.MAXIMUM': '{1}: Doğrulama Hatası: Uzunluk izin verilen maksimum değerden daha büyük: \'{0}\'.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET': 'Regex deseni boş olamaz.',
        'javax.faces.validator.RegexValidator.PATTERN_NOT_SET_detail': 'Regex deseni boş değer alamaz.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED': 'Regex deseni eşleşmedi.',
        'javax.faces.validator.RegexValidator.NOT_MATCHED_detail': '\'{0}\' ile regex deseni eşleşmedi.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION': 'Regex hatası.',
        'javax.faces.validator.RegexValidator.MATCH_EXCEPTION_detail': 'Regex hatası, \'{0}\'.',
        'javax.faces.validator.BeanValidator.MESSAGE': '{0}',
        'javax.validation.constraints.AssertFalse.message': 'Değer \'false\' (yanlış) olmak zorunda.',
        'javax.validation.constraints.AssertTrue.message': 'Değer \'true\' (doğru) olmak zorunda.',
        'javax.validation.constraints.DecimalMax.message': '{0} veya daha düşük olmalı.',
        'javax.validation.constraints.DecimalMin.message': '{0} veya daha yüksek olmalı.',
        'javax.validation.constraints.Digits.message': 'Sayısal değer sınırların dışında (&lt;{0} basamak&gt;.&lt;{1} basamak&gt; olmalı).',
        'javax.validation.constraints.Future.message': 'Gelecek bir tarih olmalı.',
        'javax.validation.constraints.Max.message': '{0} veya daha düşük olmalı.',
        'javax.validation.constraints.Min.message': '{0} veya daha yüksek olmalı',
        'javax.validation.constraints.NotNull.message': '\'null\' (boş) olmayabilir.',
        'javax.validation.constraints.Null.message': '\'null\' (boş) olmalıdır.',
        'javax.validation.constraints.Past.message': 'Geçmiş bir tarih olmalıdır.',
        'javax.validation.constraints.Pattern.message': '"{0}" ile eşleşmelidir.',
        'javax.validation.constraints.Size.message': '{0} ile {1} arasında bir değer olmalıdır.'
    }
};
